@@ -2,7 +2,7 @@ package Algorithm::Evolutionary;
 
 use Carp qw(croak);
 
-our $VERSION = '0.64_1';
+our $VERSION = '0.64_2';
 
 # Preloaded methods go here.
 
@@ -85,13 +85,8 @@ one:</p>
 =end html
 
  @InProceedings{jj:2008:PPSN,
-   author =	"Juan J. Merelo and  Antonio M. Mora and Pedro A. Castillo 
-                 and Juan L. J. Laredo and Lourdes Araujo and Ken C. Sharman 
-                 and Anna I. Esparcia-Alczar and Eva Alfaro-Cid 
-                 and Carlos Cotta",
-   title =	"Testing the Intermediate Disturbance Hypothesis: Effect of 
-                 Asynchronous Population Incorporation on Multi-Deme 
-                 Evolutionary Algorithms",
+   author =	"Juan J. Merelo and  Antonio M. Mora and Pedro A. Castillo and Juan L. J. Laredo and Lourdes Araujo and Ken C. Sharman and Anna I. Esparcia-Alcázar and Eva Alfaro-Cid and Carlos Cotta",
+   title =	"Testing the Intermediate Disturbance Hypothesis: Effect of Asynchronous Population Incorporation on Multi-Deme Evolutionary Algorithms",
    booktitle =	"Parallel Problem Solving from Nature - PPSN X",
    year = 	"2008",
    editor =	"Gunter Rudolph and Thomas Jansen and Simon Lucas and
@@ -124,7 +119,7 @@ group blog</a></p>
 
 Main author and developer is J. J. Merelo, jmerelo (at)
 geneura.ugr.es. There have also been some contributions from Javi
-Garca, fjgc (at) decsai.ugr.es and Pedro Castillo, pedro (at)
+García, fjgc (at) decsai.ugr.es and Pedro Castillo, pedro (at)
 geneura.ugr.es. Patient users that have submitted bugs include <a
 href='http://barbacana.net'>jamarier</a>. Bugs, requests and any kind
 of comment are welcome.
@@ -139,8 +134,8 @@ C<tide_float.pl>, an example of floating point vector optimization, or
 C<run_easy_ga.pl p_peaks.yaml>, which should run an example of a
 simple GA on the P_Peaks deceptive function. 
 
-Some other examples are installed: check out L<tide_bitstring.pl>,
-which you can play with to get a taste of what EA programming is like. 
+Some other examples are installed: check out L<tide_bitstring.pl>, L<tide_float.pl> and L<canonical-genetic-algorithm.pl>, 
+which you can run and play with to get a taste of what EA programming is like. 
 
 =head1 SEE ALSO
 
